daml-dit-api
====

API definitions for integrations to be hosted by DABL. This contains
the basic data types and function call definition, as well as as a
framework for simplifing the implementation of integrations.
